@@ -111,7 +111,7 @@ def save_cache(lst):
         pickle.dump(lst, lst_p)
 
 
-def show_msg():
+def show_msg(return_msg=False):
     lst = None
     try:
         with open(os.path.join(CACHE_DIR, 'data.pkl'), 'rb') as lst_p:
@@ -124,7 +124,8 @@ def show_msg():
         Fore.CYAN + Style.BRIGHT + f'"{msg.text.strip()}"'
         + Fore.YELLOW + f'\n\t\t\t\t- {msg.year}, {msg.episode}'
     )
-    return msg
+    if return_msg:
+        return msg
 
 
 def main():
